@@ -112,7 +112,6 @@ var NAVTREEINDEX0 =
 "hex2otf_8c.html#a07c4a43c1a36ee79c8a163298ff9adac":[6,0,0,1,29],
 "hex2otf_8c.html#a0c8186d9b9b7880309c27230bbb5e69d":[6,0,0,1,26],
 "hex2otf_8c.html#a0d187cc87528ef35478afd7a68309f08":[6,0,0,1,38],
-"hex2otf_8c.html#a0d20b69b0ad703df78459e1033d5c1d4":[6,0,0,1,75],
 "hex2otf_8c.html#a0d4560c5d562d31a33f092bb579f8397":[6,0,0,1,47],
 "hex2otf_8c.html#a0ddc03905c4918e04aa1e54a7c1716b1":[6,0,0,1,63],
 "hex2otf_8c.html#a0ddf1224851353fc92bfbff6f499fa97":[6,0,0,1,67],
@@ -144,6 +143,7 @@ var NAVTREEINDEX0 =
 "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8ca0bbdc63e5d0938274b80230bc55d03b8":[6,0,0,1,34,1],
 "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8caf18243d8ef6a7f601ae03a6cffbabadd":[6,0,0,1,34,0],
 "hex2otf_8c.html#a6c1e982fdc6c51b9f84051daa2e71936":[6,0,0,1,55],
+"hex2otf_8c.html#a6ffce9764ba647abe9b3bee1aaadd3a7":[6,0,0,1,76],
 "hex2otf_8c.html#a77e92e56b5af63bc912ed4cbf5f5c585":[6,0,0,1,9],
 "hex2otf_8c.html#a77ff68152c5cb38605010bc7621b0722":[6,0,0,1,79],
 "hex2otf_8c.html#a79d8a322be9d9131b684a9ea67abe05e":[6,0,0,1,61],
@@ -165,7 +165,6 @@ var NAVTREEINDEX0 =
 "hex2otf_8c.html#a97af00050b8fd6b7e7b81c7027e4c8e6":[6,0,0,1,73],
 "hex2otf_8c.html#a97c9b2ae58f5989d68e639715c3f9df9":[6,0,0,1,59],
 "hex2otf_8c.html#a97fbabab590ac85657edb01474da7d50":[6,0,0,1,30],
-"hex2otf_8c.html#a9c4b081f1e1ad60def15811c71a936f2":[6,0,0,1,76],
 "hex2otf_8c.html#aa52cd46a50cdc2040a72e5c7ecfa944b":[6,0,0,1,74],
 "hex2otf_8c.html#aaa5713bb2ecdf81c430009179b806232":[6,0,0,1,32],
 "hex2otf_8c.html#ab37b4f7111692f8d1163bafd2aab831e":[6,0,0,1,52],
@@ -174,10 +173,11 @@ var NAVTREEINDEX0 =
 "hex2otf_8c.html#abce67139ad0bc979ef080a694e60fb36":[6,0,0,1,21],
 "hex2otf_8c.html#ac2eec01939cae967aa9882b2517288a1":[6,0,0,1,71],
 "hex2otf_8c.html#ac928f7761fc187ff86f33805309bec21":[6,0,0,1,65],
-"hex2otf_8c.html#ac947cbe076da5fbab8f5e4c1c821b7a6":[6,0,0,1,48],
+"hex2otf_8c.html#acfd4c464cd710f2311581f0002c06020":[6,0,0,1,48],
 "hex2otf_8c.html#ad0d9350c8943e5550a14f1cff5580a6c":[6,0,0,1,6],
 "hex2otf_8c.html#ad0f95bf4a3a4a28b173b971e246b8745":[6,0,0,1,15],
 "hex2otf_8c.html#ad77c441582f862d494a734eb9855dd41":[6,0,0,1,78],
+"hex2otf_8c.html#ae19e0a10c9b6b5aaf1878cac27ea9541":[6,0,0,1,75],
 "hex2otf_8c.html#ae28f2f636e4d3dd3b5784a3bc3f92b58":[6,0,0,1,77],
 "hex2otf_8c.html#ae2b46edf2ac290c695e2b27d16f1b380":[6,0,0,1,80],
 "hex2otf_8c.html#ae32c0f82cbb6a4d8ece0559f1c7b74f4":[6,0,0,1,49],
@@ -210,27 +210,27 @@ var NAVTREEINDEX0 =
 "index.html#Title":[0],
 "johab2syllables_8c.html":[6,0,0,3],
 "johab2syllables_8c.html#a0ddf1224851353fc92bfbff6f499fa97":[6,0,0,3,0],
-"johab2syllables_8c.html#a853216ac51aa181669ff4d3de74058a7":[6,0,0,3,1],
+"johab2syllables_8c.html#a402ea961bfc2ffeee61e3a7c330b1559":[6,0,0,3,1],
 "johab2syllables_8c_source.html":[6,0,0,3],
 "pages.html":[],
-"struct_buffer.html":[5,0,0],
-"struct_font.html":[5,0,1],
-"struct_glyph.html":[5,0,2],
-"struct_glyph.html#a08ed20f3df1902ce776f6e1fccd089b9":[5,0,2,2],
-"struct_glyph.html#a7fb4dc03b71777de880164eee4ffbc51":[5,0,2,4],
-"struct_glyph.html#aa309ceb984d5524ef7dab0e8927fdd64":[5,0,2,1],
-"struct_glyph.html#abbbc1113c6e10dc0fa986abbb7f7665e":[5,0,2,0],
-"struct_glyph.html#ac113da35f4193641855eaf51547f9b43":[5,0,2,5],
-"struct_glyph.html#ada6b8b4b9419096c413b5a29dbc54aac":[5,0,2,3],
-"struct_name_pair.html":[5,0,3],
-"struct_options.html":[5,0,4],
-"struct_p_a_r_a_m_s.html":[5,0,5],
-"struct_table.html":[5,0,6],
-"struct_table_record.html":[5,0,7],
+"structBuffer.html":[5,0,0],
+"structFont.html":[5,0,1],
+"structGlyph.html":[5,0,2],
+"structGlyph.html#a08ed20f3df1902ce776f6e1fccd089b9":[5,0,2,2],
+"structGlyph.html#a7fb4dc03b71777de880164eee4ffbc51":[5,0,2,4],
+"structGlyph.html#aa309ceb984d5524ef7dab0e8927fdd64":[5,0,2,1],
+"structGlyph.html#abbbc1113c6e10dc0fa986abbb7f7665e":[5,0,2,0],
+"structGlyph.html#ac113da35f4193641855eaf51547f9b43":[5,0,2,5],
+"structGlyph.html#ada6b8b4b9419096c413b5a29dbc54aac":[5,0,2,3],
+"structNamePair.html":[5,0,3],
+"structOptions.html":[5,0,4],
+"structPARAMS.html":[5,0,5],
+"structTable.html":[5,0,6],
+"structTableRecord.html":[5,0,7],
 "unibdf2hex_8c.html":[6,0,0,4],
 "unibdf2hex_8c.html#a2e467ad6d1fb7b24985a45af8b1e7ad1":[6,0,0,4,1],
+"unibdf2hex_8c.html#a840291bc02cba5474a4cb46a9b9566fe":[6,0,0,4,3],
 "unibdf2hex_8c.html#ad7871643c05865c80f5d8050aead2b57":[6,0,0,4,0],
-"unibdf2hex_8c.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[6,0,0,4,3],
 "unibdf2hex_8c.html#afd5dcd82c8e611d544ad18b798c54d50":[6,0,0,4,2],
 "unibdf2hex_8c_source.html":[6,0,0,4],
 "unibmp2hex_8c.html":[6,0,0,5],
